@@ -1,14 +1,17 @@
-## Copyright (C) 2004 Etienne Grossmann.  All rights reserved.
+## Copyright (C) 2000 Etienne Grossmann <etienne@egdn.net>
 ##
-## This program is free software; you can redistribute it and/or modify it
-## under the terms of the GNU General Public License as published by the
-## Free Software Foundation; either version 2, or (at your option) any
-## later version.
+## This program is free software; you can redistribute it and/or modify it under
+## the terms of the GNU General Public License as published by the Free Software
+## Foundation; either version 3 of the License, or (at your option) any later
+## version.
 ##
-## This is distributed in the hope that it will be useful, but WITHOUT
+## This program is distributed in the hope that it will be useful, but WITHOUT
 ## ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-## FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
-## for more details.
+## FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
+## details.
+##
+## You should have received a copy of the GNU General Public License along with
+## this program; if not, see <http://www.gnu.org/licenses/>.
 
 ##       errors = test_struct
 ##
@@ -23,9 +26,6 @@
 ## test counts are displayed at the end of the script (if it is reached).
 ##
 
-## Author:        Etienne Grossmann <etienne@cs.uky.edu>
-## $Id: test_struct.m 5489 2008-12-11 16:50:49Z thomas-weber $
-
 1 ;
 global test_struct_errors  ;
 global test_struct_cnt  ;
